This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]

[PATCH]: Fix typoes and spelling errors


The enclosed patch fixes a bunch of typoes and spelling errors.
Unless I hear otherwise, I'll be committing this early next week.

        --jtc

2000-10-27  J.T. Conklin  <jtc@redback.com>

	* gdbarch.sh, hp-psymtab-read.c, hpread.c, m3-nat.c, mcore-tdep.c, 
	monitor.c, regcache.c, somread.c, tracepoint.c: Fix spelling errors 
	in comments.

	* gnu-nat.c (S_exception_raise_request): Fix typos and spelling 
	errors in strings.
	* m3-nat.c (intercept_exec_calls, mach_thread_parse_id): Likewise.
	* mcore-tdep.c (mcore_analyze_prologue): Likewise.
	* mips-tdep.c (mips16_next_pc, _initialize_mips_tdep): Likewise.
	* remote-e7000.c (e7000_start_remote): Likewise.
	* remote-rdp.c (handle_swi): Likewise.
	* remote-vx.c (vx_load_command): Likewise.
	* sh-tdep.c (sh_do_pseudo_register): Likewise.
	* sol-thread.c (td_err_string): Likewise.
	* symtab.c (decode_line_2): Likewise.

Index: gdbarch.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.c,v
retrieving revision 1.45
diff -u -r1.45 gdbarch.c
--- gdbarch.c	2000/10/27 19:17:56	1.45
+++ gdbarch.c	2000/10/27 22:16:24
@@ -4026,7 +4026,7 @@
   (*curr)->arches = NULL;
   (*curr)->next = NULL;
   /* When non- multi-arch, install what ever target dump routine we've
-     been provided - hopefully that routine has been writen correct
+     been provided - hopefully that routine has been written correct
      and works regardless of multi-arch. */
   if (!GDB_MULTI_ARCH && dump_tdep != NULL
       && startup_gdbarch.dump_tdep == NULL)
Index: gdbarch.sh
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.sh,v
retrieving revision 1.46
diff -u -r1.46 gdbarch.sh
--- gdbarch.sh	2000/10/27 19:17:56	1.46
+++ gdbarch.sh	2000/10/27 22:16:25
@@ -1724,7 +1724,7 @@
   (*curr)->arches = NULL;
   (*curr)->next = NULL;
   /* When non- multi-arch, install what ever target dump routine we've
-     been provided - hopefully that routine has been writen correct
+     been provided - hopefully that routine has been written correct
      and works regardless of multi-arch. */
   if (!GDB_MULTI_ARCH && dump_tdep != NULL
       && startup_gdbarch.dump_tdep == NULL)
Index: gnu-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/gnu-nat.c,v
retrieving revision 1.7
diff -u -r1.7 gnu-nat.c
--- gnu-nat.c	2000/08/31 03:19:06	1.7
+++ gnu-nat.c	2000/10/27 22:16:28
@@ -1659,13 +1659,13 @@
 	{
 	  if (thread->exc_port == port)
 	    {
-	      inf_debug (waiting_inf, "Handler is thread exeption port <%d>",
+	      inf_debug (waiting_inf, "Handler is thread exception port <%d>",
 			 thread->saved_exc_port);
 	      inf->wait.exc.handler = thread->saved_exc_port;
 	    }
 	  else
 	    {
-	      inf_debug (waiting_inf, "Handler is task exeption port <%d>",
+	      inf_debug (waiting_inf, "Handler is task exception port <%d>",
 			 inf->task->saved_exc_port);
 	      inf->wait.exc.handler = inf->task->saved_exc_port;
 	      assert (inf->task->exc_port == port);
Index: hpread.c
===================================================================
RCS file: /cvs/src/src/gdb/hpread.c,v
retrieving revision 1.6
diff -u -r1.6 hpread.c
--- hpread.c	2000/10/24 21:13:08	1.6
+++ hpread.c	2000/10/27 22:16:31
@@ -658,8 +658,8 @@
 
 /* Get the low address associated with some symbol (typically the start
    of a particular source file or module).  Since that information is not
-   stored as part of the DNTT_TYPE_MODULE or DNTT_TYPE_SRCFILE symbol we must infer it from
-   the existance of DNTT_TYPE_FUNCTION symbols.  */
+   stored as part of the DNTT_TYPE_MODULE or DNTT_TYPE_SRCFILE symbol we
+   must infer it from the existence of DNTT_TYPE_FUNCTION symbols.  */
 
 static unsigned long
 hpread_get_textlow (int global, int index, struct objfile *objfile)
Index: m3-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/m3-nat.c,v
retrieving revision 1.5
diff -u -r1.5 m3-nat.c
--- m3-nat.c	2000/09/15 07:08:11	1.5
+++ m3-nat.c	2000/10/27 22:16:34
@@ -692,7 +692,7 @@
   CHK ("mach_port_extract_right (bsd server send)", ret);
 
   if (acquired != MACH_MSG_TYPE_PORT_SEND)
-    error ("Incorrect right extracted, send right to bsd server excpected");
+    error ("Incorrect right extracted, send right to bsd server expected");
 
   ret = mach_port_insert_right (inferior_task,
 				original_server_port_name,
@@ -719,7 +719,7 @@
   CHK ("mach_port_extract_right (exec_reply)", ret);
 
   if (acquired != MACH_MSG_TYPE_PORT_SEND_ONCE)
-    error ("Incorrect right extracted, send once excpected for exec reply");
+    error ("Incorrect right extracted, send once expected for exec reply");
 
   ret = mach_port_move_member (mach_task_self (),
 			       fake_server,
@@ -1540,7 +1540,7 @@
 {
   int mid;
   if (arg == 0)
-    error ("thread id excpected");
+    error ("thread id expected");
   mid = parse_thread_id (arg, 0, 1);
 
   return mid;
Index: mcore-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/mcore-tdep.c,v
retrieving revision 1.3
diff -u -r1.3 mcore-tdep.c
--- mcore-tdep.c	2000/10/27 15:02:42	1.3
+++ mcore-tdep.c	2000/10/27 22:16:34
@@ -118,7 +118,7 @@
 /* The base of the current frame is in a frame pointer register.
    This register is noted in frame_extra_info->fp_regnum.
 
-   Note that the existance of an FP might also indicate that the
+   Note that the existence of an FP might also indicate that the
    function has called alloca. */
 #define MY_FRAME_IN_FP 0x2
 
@@ -336,7 +336,7 @@
       if (IS_SUBI0 (insn))
 	{
 	  int offset = 1 + ((insn >> 4) & 0x1f);
-	  mcore_insn_debug (("MCORE: got subi r0,%d; contnuing\n", offset));
+	  mcore_insn_debug (("MCORE: got subi r0,%d; continuing\n", offset));
 	  framesize += offset;
 	  continue;
 	}
Index: mips-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/mips-tdep.c,v
retrieving revision 1.33
diff -u -r1.33 mips-tdep.c
--- mips-tdep.c	2000/10/27 15:02:42	1.33
+++ mips-tdep.c	2000/10/27 22:16:38
@@ -1120,7 +1120,7 @@
 	  pc += 4;		/* Dont be setting breakpints on the second half */
 	  break;
 	default:
-	  printf ("Filtered - next PC probably incorrrect due to jump inst\n");
+	  printf ("Filtered - next PC probably incorrect due to jump inst\n");
 	  pc += 2;
 	  break;
 	}
@@ -4565,7 +4565,7 @@
 	   "Select single-precision MIPS floating-point coprocessor.",
 	   &mipsfpulist);
   add_cmd ("double", class_support, set_mipsfpu_double_command,
-	   "Select double-precision MIPS floating-point coprocessor .",
+	   "Select double-precision MIPS floating-point coprocessor.",
 	   &mipsfpulist);
   add_alias_cmd ("on", "double", class_support, 1, &mipsfpulist);
   add_alias_cmd ("yes", "double", class_support, 1, &mipsfpulist);
Index: monitor.c
===================================================================
RCS file: /cvs/src/src/gdb/monitor.c,v
retrieving revision 1.12
diff -u -r1.12 monitor.c
--- monitor.c	2000/09/24 04:42:12	1.12
+++ monitor.c	2000/10/27 22:16:39
@@ -23,7 +23,7 @@
 /* This file was derived from various remote-* modules. It is a collection
    of generic support functions so GDB can talk directly to a ROM based
    monitor. This saves use from having to hack an exception based handler
-   into existance, and makes for quick porting.
+   into existence, and makes for quick porting.
 
    This module talks to a debug monitor called 'MONITOR', which
    We communicate with MONITOR via either a direct serial line, or a TCP
Index: regcache.c
===================================================================
RCS file: /cvs/src/src/gdb/regcache.c,v
retrieving revision 1.10
diff -u -r1.10 regcache.c
--- regcache.c	2000/09/01 17:59:26	1.10
+++ regcache.c	2000/10/27 22:16:40
@@ -717,7 +717,7 @@
    Ditto for write_pc.
 
    1999-06-08: The following were re-written so that it assumes the
-   existance of a TARGET_READ_PC et.al. macro.  A default generic
+   existence of a TARGET_READ_PC et.al. macro.  A default generic
    version of that macro is made available where needed.
 
    Since the ``TARGET_READ_PC'' et.al. macro is going to be controlled
Index: remote-e7000.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-e7000.c,v
retrieving revision 1.9
diff -u -r1.9 remote-e7000.c
--- remote-e7000.c	2000/10/03 22:42:32	1.9
+++ remote-e7000.c	2000/10/27 22:16:40
@@ -627,7 +627,7 @@
   if (!sync)
     {
       fprintf_unfiltered (gdb_stderr, "Giving up after %d tries...\n", try);
-      error ("Unable to syncronize with target.\n");
+      error ("Unable to synchronize with target.\n");
     }
 
   puts_e7000debug ("\r");
Index: remote-rdp.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-rdp.c,v
retrieving revision 1.6
diff -u -r1.6 remote-rdp.c
--- remote-rdp.c	2000/10/12 21:39:21	1.6
+++ remote-rdp.c	2000/10/27 22:16:41
@@ -970,7 +970,7 @@
 	  break;
 
 	default:
-	  error ("Unimplented SWI argument");
+	  error ("Unimplemented SWI argument");
 	}
 
       type = type >> 2;
Index: remote-vx.c
===================================================================
RCS file: /cvs/src/src/gdb/remote-vx.c,v
retrieving revision 1.8
diff -u -r1.8 remote-vx.c
--- remote-vx.c	2000/10/16 06:42:28	1.8
+++ remote-vx.c	2000/10/27 22:16:42
@@ -713,7 +713,7 @@
 Kill the target task? "))
 	target_kill ();
       else
-	error ("Load cancelled.");
+	error ("Load canceled.");
     }
 
   QUIT;
Index: sh-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/sh-tdep.c,v
retrieving revision 1.14
diff -u -r1.14 sh-tdep.c
--- sh-tdep.c	2000/07/31 16:25:36	1.14
+++ sh-tdep.c	2000/10/27 22:16:43
@@ -1661,7 +1661,7 @@
 sh_do_pseudo_register (int regnum)
 {
   if (regnum < NUM_REGS || regnum >= NUM_REGS + NUM_PSEUDO_REGS)
-    internal_error ("Invalid pasudo register number %d\n", regnum);
+    internal_error ("Invalid pseudo register number %d\n", regnum);
   else if (regnum >= NUM_REGS && 
 	   regnum < gdbarch_tdep (current_gdbarch)->FV0_REGNUM)
     do_dr_register_info (regnum);
Index: sol-thread.c
===================================================================
RCS file: /cvs/src/src/gdb/sol-thread.c,v
retrieving revision 1.18
diff -u -r1.18 sol-thread.c
--- sol-thread.c	2000/10/18 03:29:25	1.18
+++ sol-thread.c	2000/10/27 22:16:44
@@ -217,7 +217,7 @@
     {TD_NOAPLIC, "Operation not applicable to"},
     {TD_NOTSD, "No thread specific data for this thread"},
     {TD_MALLOC, "Malloc failed"},
-    {TD_PARTIALREG, "Only part of register set was writen/read"},
+    {TD_PARTIALREG, "Only part of register set was written/read"},
     {TD_NOXREGS, "X register set not available for given thread"}
   };
   const int td_err_size = sizeof td_err_table / sizeof (struct string_map);
Index: somread.c
===================================================================
RCS file: /cvs/src/src/gdb/somread.c,v
retrieving revision 1.7
diff -u -r1.7 somread.c
--- somread.c	2000/08/27 22:30:29	1.7
+++ somread.c	2000/10/27 22:16:45
@@ -115,7 +115,7 @@
 
      There's nothing in the header which easily allows us to do
      this.  The only reliable way I know of is to check for the
-     existance of a $SHLIB_INFO$ section with a non-zero size.  */
+     existence of a $SHLIB_INFO$ section with a non-zero size.  */
   /* The code below is not a reliable way to check whether an
    * executable is dynamic, so I commented it out - RT
    * shlib_info = bfd_get_section_by_name (objfile->obfd, "$SHLIB_INFO$");
Index: symtab.c
===================================================================
RCS file: /cvs/src/src/gdb/symtab.c,v
retrieving revision 1.18
diff -u -r1.18 symtab.c
--- symtab.c	2000/10/27 15:02:42	1.18
+++ symtab.c	2000/10/27 22:16:48
@@ -3331,7 +3331,7 @@
       num = atoi (args);
 
       if (num == 0)
-	error ("cancelled");
+	error ("canceled");
       else if (num == 1)
 	{
 	  if (canonical_arr)
Index: tracepoint.c
===================================================================
RCS file: /cvs/src/src/gdb/tracepoint.c,v
retrieving revision 1.10
diff -u -r1.10 tracepoint.c
--- tracepoint.c	2000/09/01 00:12:10	1.10
+++ tracepoint.c	2000/10/27 22:16:49
@@ -1265,7 +1265,7 @@
       printf_filtered ("Don't know LOC_UNRESOLVED %s\n", SYMBOL_NAME (sym));
       break;
     case LOC_OPTIMIZED_OUT:
-      printf_filtered ("%s has been optimized out of existance.\n",
+      printf_filtered ("%s has been optimized out of existence.\n",
 		       SYMBOL_NAME (sym));
       break;
     }


Index: hp-psymtab-read.c
===================================================================
RCS file: /cvs/src/src/gdb/hp-psymtab-read.c,v
retrieving revision 1.6
diff -u -r1.6 hp-psymtab-read.c
--- hp-psymtab-read.c	2000/08/31 03:19:06	1.6
+++ hp-psymtab-read.c	2000/10/27 22:16:30
@@ -70,7 +70,7 @@
 #include <stdlib.h>
 #include <string.h>
 
 /* check for the existance of a file, given its full pathname */
 int
 file_exists (char *filename)
 {
@@ -103,7 +103,7 @@
 /* Call PXDB to process our file.
 
    Approach copied from DDE's "dbgk_run_pxdb".  Note: we
-   don't check for BSD location of pxdb, nor for existance
+   don't check for BSD location of pxdb, nor for existence
    of pxdb itself, etc.
 
    NOTE: uses system function and string functions directly.
@@ -2104,8 +2104,8 @@
 
 /* Get the low address associated with some symbol (typically the start
    of a particular source file or module).  Since that information is not
-   stored as part of the DNTT_TYPE_MODULE or DNTT_TYPE_SRCFILE symbol we must infer it from
-   the existance of DNTT_TYPE_FUNCTION symbols.  */
+   stored as part of the DNTT_TYPE_MODULE or DNTT_TYPE_SRCFILE symbol we
+   must infer it from the existence of DNTT_TYPE_FUNCTION symbols.  */
 
 static unsigned long
 hpread_get_textlow (int global, int index, struct objfile *objfile,
@@ -70,7 +70,7 @@
 #include <string.h>
 
-/* check for the existance of a file, given its full pathname */
+/* check for the existence of a file, given its full pathname */
 int
 file_exists (char *filename)
-- 
J.T. Conklin
RedBack Networks

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]